@@ -19,9 +19,7 @@ require 'spec_helper'
 describe 'tripleo::profile::base::gnocchi::api' do
   shared_examples_for 'tripleo::profile::base::gnocchi::api' do
     let(:pre_condition) do
-      "
-        class { '::tripleo::profile::base::gnocchi': step => #{params[:step]}, }
-      "
+      "class { '::tripleo::profile::base::gnocchi': step => #{params[:step]}, }"
     end
 
     context 'with step less than 3' do
@@ -38,9 +36,9 @@ describe 'tripleo::profile::base::gnocchi::api' do
       }
     end
 
-    context 'with step 4 on bootstrap' do
+    context 'with step 3 on bootstrap' do
       let(:params) { {
-        :step => 4,
+        :step => 3,
         :bootstrap_node => 'node.example.com',
         :gnocchi_redis_password => 'gnocchi',
         :redis_vip => '127.0.0.1'
@@ -53,6 +51,20 @@ describe 'tripleo::profile::base::gnocchi::api' do
       }
     end
 
+    context 'with step 3' do
+      let(:params) { {
+        :step => 3,
+        :gnocchi_redis_password => 'gnocchi',
+        :redis_vip => '127.0.0.1'
+      } }
+
+      it {
+        is_expected.to_not contain_class('gnocchi::db::sync')
+        is_expected.to contain_class('gnocchi::api')
+        is_expected.to contain_class('gnocchi::wsgi::apache')
+      }
+    end
+
     context 'with step 4' do
       let(:params) { {
         :step => 4,
@@ -93,8 +105,7 @@ describe 'tripleo::profile::base::gnocchi::api' do
         :step => 4,
         :gnocchi_backend => 'rbd',
         :gnocchi_redis_password => 'gnocchi',
-        :redis_vip => '127.0.0.1',
-        :gnocchi_rbd_client_name => 'openstack'
+        :redis_vip => '127.0.0.1'
       } }
 
       it {
@@ -104,7 +115,6 @@ describe 'tripleo::profile::base::gnocchi::api' do
           :coordination_url => 'redis://:gnocchi@127.0.0.1:6379/'
         )
         is_expected.to contain_class('gnocchi::storage::ceph')
-        is_expected.to contain_exec('exec-setfacl-openstack-gnocchi')
       }
     end
 
@@ -119,6 +129,10 @@ describe 'tripleo::profile::base::gnocchi::api' do
       it {
         is_expected.to contain_class('gnocchi::api')
         is_expected.to contain_class('gnocchi::wsgi::apache')
+        is_expected.to contain_exec('run gnocchi upgrade with storage').with(
+          :command => 'gnocchi-upgrade --config-file=/etc/gnocchi/gnocchi.conf',
+          :path    => ['/usr/bin', '/usr/sbin']
+        )
       }
     end
   end
